###############################################################
### Example, Section 6.1 - part I (without standardisation)
### Cyclists hospitalized with a head injury
### Vencalek, Hron, Filzmoser

### libraries: VGAM 
### data:      accidents-head.csv 
### R-files:   RealData-Functions.R
###############################################################

library(VGAM)

x = read.csv2("accidents-head.csv",header=FALSE)
names(x) = c("year","group1","group2","group3")

source("RealData-Functions.R")

################################################################

Years = dim(x)[1]
Start = x[1,1]
coordinates = coord(selected.data(x,Start,Years)[,-1])

### parameters + CIs 
    # (a1,a2,b1,b2)
    # column 1: point estimation
    # columns 2-3: 95% CI
  print(coda.param <- my.coda(selected.data(x,Start,Years)[,-1],1:Years-1,typ="CI"))
  print(glm.param  <- my.glm(selected.data(x,Start,Years)[,-1],1:Years-1,typ="CI"))

### models:

  model.coda1 = my.coda(selected.data(x,Start,Years)[,-1],1:Years-1,typ="model",ktery=1)
  model.coda2 = my.coda(selected.data(x,Start,Years)[,-1],1:Years-1,typ="model",ktery=2)
  model.glm   =  my.glm(selected.data(x,Start,Years)[,-1],1:Years-1,typ="model")

### TABLE 2:
  ### Comparison of the point estimates:
  comp1 = data.frame(coda.param[,1],glm.param[,1],coda.param[,1]-glm.param[,1])
  names(comp1) = c("coda","glm","difference")
  print("Comparison of the point estimates:")
  print(comp1)
  # xtable(comp1,digits=4)
  
  ### Comparison of the standard deviations:
  sd.coda = (coda.param[,3] - coda.param[,2])/(2*qt(0.975,Years-2))
  sd.glm  = ( glm.param[,3] -  glm.param[,2])/(2*qnorm(0.975))
  comp2 = data.frame(sd.coda,sd.glm,sd.coda/sd.glm)
  names(comp2) = c("coda","glm","ratio")
  print("Comparison of the standard deviations:")
  print(comp2)  
  
################################################################
### graphics
################################################################
  
  
### FIGURE 3: barplot
  #pdf("graf-accidents.pdf",height=4.5,width = 7.5)
  Barvy = c("gray25","gray50","gray85")
  par(xpd=TRUE, mar=c(6,4.4,1,1),mfrow=c(1,1))
  graf(selected.data(x,Start,Years),barvy=Barvy,"Proportion")
  #graf(selected.data(x,Start,Years),barvy=heat.colors(3),"Proportion")
  legend(x=0.7,y=-0.2,horiz=TRUE, legend=c("0-14 years","15-26 years","older than 26 years"),
         fill=Barvy)
  #dev.off()
  
  
  
### FIGURE 4: coordinates and fitted lines  
#pdf("graf-accidents-fit.pdf",height=4,width = 12)
  par(mfrow=c(1,2),mar=c(4,5,1,1))
  popis = c('1999',"'00","'01","'02","'03","'04","'05","'06","'07","'08",'2009')
  
  plot(coordinates$z1,pch=20,axes=FALSE,frame=TRUE,cex.lab=1.3,
       xlab = "year", ylab = expression(paste("empirical ln(", pi[1]/pi[2],")")))
      axis(1,1:11,popis)
      axis(2)
  points(model.coda1$fit,type="l",col=2,lwd=2)
  points(coord(model.glm@fitted.values)$z1,type="l",col=4,lwd=2)
  
  plot(coordinates$z2,pch=20,axes=FALSE,frame=TRUE,cex.lab=1.3,
       xlab = "year", ylab = expression(paste("empirical ln(",sqrt(pi[1]*pi[2])/pi[3],")")))
      axis(1,1:11,popis)
      axis(2)
  points(model.coda2$fit,type="l",col=2,lwd=2)
  points(coord(model.glm@fitted.values)$z2,type="l",col=4,lwd=2)
#dev.off()

