###############################################################
### Section 4
### Numerical Illustrations
### Vencalek, Hron, Filzmoser

### R-files:   simul-auxiliary.R


###########################################################################################
########### 4.1 Dependence of the variance matrix on the parameters from the multinomial model
###########################################################################################


### parameters (input):
a1 = 0
a2 = 0
b1 = -0.4
b2 = 0.4

source("simul-auxiliary.R")
  round(data.frame(P,v1,v2,kor),2)
  # xtable(round(data.frame(P,v1,v2,kor),2))

N = 1000    # parameter of the multinomial distribution (total number of observations)
opak = 100   # number of repetitions of the simulation


Di = di+1

Z1 = matrix(ncol=Di,nrow=opak)
Z2 = matrix(ncol=Di,nrow=opak)

############################################################################################

for (oi in 1:opak)
{
  set.seed(oi)
  
  # generating the data
  D = matrix(ncol=3,nrow=Di)
  for(i in 1:Di)
  {aux = runif(N)
   X = 1+1*(aux>pi1[i])+1*(aux>(pi1[i]+pi2[i]))
   D[i,] = c(sum(X==1),sum(X==2),sum(X==3))  }
  
  pi = D/apply(D,1,sum)
  z1 = log(pi[,1]/pi[,2])
  z2 = log(pi[,2]/pi[,3])

  Z1[oi,] = z1
  Z2[oi,] = z2
}

############################################################################################



#pdf("Fig1.pdf",height=10,width=20)
par(mfrow=c(1,2),mar=c(6,6.2,1.1,1),mgp=c(4,1.7,0))
  plot(as.numeric(t(Z1))~as.factor(rep(x,opak)),cex.lab=2.5,cex.axis=2.5,
       xlab = "x (time)", ylab=expression(Z[1]))
  plot(as.numeric(t(Z2))~as.factor(rep(x,opak)),cex.lab=2.5,cex.axis=2.5,
       xlab = "x (time)", ylab=expression(Z[2]))
#dev.off()





###########################################################################################
########### 4.2 Dependence of the variance matrix on total counts in observations
###########################################################################################


### parameters (input):
a1 = 0.2
a2 = 0.5
b1 = 0
b2 = 0

source("simul-auxiliary.R")


parametr1 = 2
N = c(rep(100,parametr1),rep(10000,11-parametr1))    # parameter of the multinomial distribution (total number of observations)
opak = 100   # number of repetitions of the simulation


Di = di+1

Z1 = matrix(ncol=Di,nrow=opak)
Z2 = matrix(ncol=Di,nrow=opak)

pva1=numeric()
pva2=numeric()
############################################################################################

for (oi in 1:opak)
{
  set.seed(oi)
  
  # generating the data
  D = matrix(ncol=3,nrow=Di)
  for(i in 1:Di)
  {aux = runif(N[i])
   X = 1+1*(aux>pi1[i])+1*(aux>(pi1[i]+pi2[i]))
   D[i,] = c(sum(X==1),sum(X==2),sum(X==3))  }
  
  pi = D/apply(D,1,sum)
  z1 = log(pi[,1]/pi[,2])
  z2 = log(pi[,2]/pi[,3])
  
  Z1[oi,] = z1
  Z2[oi,] = z2
  
  z = as.matrix(cbind(z1,z2))
  m = lm(z~x)
  pva1[oi] = summary(m)[[1]]$coef[2,4]
  pva2[oi] = summary(m)[[2]]$coef[2,4]
}

############################################################################################

(p1 = sum(pva1<0.05)/opak)
p1+c(-1,1)*qnorm(0.975)*sqrt(p1*(1-p1)/opak)
(p2 = sum(pva2<0.05)/opak)
p2+c(-1,1)*qnorm(0.975)*sqrt(p2*(1-p2)/opak)


#pdf("Fig2.pdf",height=10,width=20)
  par(mfrow=c(1,2),mar=c(6,6,1,1),mgp=c(3,1.3,0))
  plot(as.numeric(t(Z1))~as.factor(rep(x,opak)),cex.lab=2,cex.axis=2,
     xlab = "x (time)", ylab=expression(Z[1]))
  plot(as.numeric(t(Z2))~as.factor(rep(x,opak)),cex.lab=2,cex.axis=2,
     xlab = "x (time)", ylab=expression(Z[2]))
#dev.off()
